@@ -3,6 +3,20 @@ import pandas as pd
 from GoogleApiSupport import auth
 
 
+def create(title):
+    service = auth.get_service("sheets")
+    spreadsheet = {
+        'properties': {
+            'title': title
+        }
+    }
+    spreadsheet = service.spreadsheets().create(body=spreadsheet,
+                                                fields='spreadsheetId') \
+        .execute()
+    print(f"Spreadsheet ID: {(spreadsheet.get('spreadsheetId'))}")
+    return spreadsheet.get('spreadsheetId')
+
+
 def change_sheet_title(newFileName, fileId):
     service = auth.get_service("sheets")
 
@@ -78,7 +92,7 @@ def get_sheet_charts(spreadsheetId, sheetName):
             return sheet_page['charts']
 
 
-def sheet_to_pandas(spreadsheetId, sheetName='', sheetRange='', index=''):
+def sheet_to_pandas(spreadsheetId, sheetName='', sheetRange='', index='', has_header=True ):
     '''
     PARAMETERS:
         service - Api service
@@ -97,7 +111,14 @@ def sheet_to_pandas(spreadsheetId, sheetName='', sheetRange='', index=''):
         range=sheetName+sheetRange
     ).execute()
 
-    headers = newresult['values'].pop(0)
+    if has_header:
+        headers = newresult['values'].pop(0)
+    else:
+        max_len = 0 
+        for row in newresult['values']:
+            if len(row) > max_len:
+                max_len = len(row)
+        headers = get_range_column_names(max_len)
 
     if (index == ''):
         return pd.DataFrame(newresult['values'], columns=headers)
@@ -114,3 +135,28 @@ def clear_sheet(spreadsheetId, sheetName, sheetRange=''):
         spreadsheetId=spreadsheetId,
         range=sheetName+sheetRange
     ).execute()
+
+# Complementary functions
+
+def get_column_name(n):
+
+	# initialize output string as empty
+	result = ''
+
+	while n > 0:
+
+		# find the index of the next letter and concatenate the letter
+		# to the solution
+
+		# here index 0 corresponds to `A`, and 25 corresponds to `Z`
+		index = (n - 1) % 26
+		result += chr(index + ord('A'))
+		n = (n - 1) // 26
+
+	return result[::-1]
+
+def get_range_column_names(r):
+    output = []
+    for i in range(r):
+        output.append(get_column_name(i))
+    return output
\ No newline at end of file
